import 'package:witsystem_device_plugin/device/DeviceFunctionType.dart';

import '../WitsystemSDK.dart';
import 'dart:convert' as convert;

///设备管理

class DeviceManage extends WisystemSDk {
  factory DeviceManage() => _getInstance();

  static DeviceManage get instance => _getInstance();
  static DeviceManage? _instance;

  DeviceManage._internal();

  static DeviceManage _getInstance() {
    _instance ??= DeviceManage._internal();
    return _instance!;
  }

  /// 获得设备列表
  Future<List<dynamic>> deviceList() async {
    try {
      String json = await methodChannel.invokeMethod("deviceList");
      return Future.value(convert.json.decode(json));
    } catch (e) {
      rethrow;
    }
  }

  /// 获得指定设备的信息
  Future<Map<String, dynamic>> device(String deviceId) async {
    try {
      String json =
          await methodChannel.invokeMethod("device", {"deviceId": deviceId});
      return Future.value(convert.json.decode(json));
    } catch (e) {
      rethrow;
    }
  }

  ///查询指定设备支付支持指定的功能或者是硬件
  Future<bool> isDeviceFunction(
      String deviceId, DeviceFunctionType type) async {
    try {
      return await methodChannel.invokeMethod(
          "isDeviceFunction", {"deviceId": deviceId, "type": type.name});
    } catch (e) {
      rethrow;
    }
  }

  ///查询指定设备的用户列表
  Future<bool> deviceUserList(String deviceId) async {
    try {
      String str = await methodChannel
          .invokeMethod("deviceUserList", {"deviceId": deviceId});
      var decode = convert.json.decode(str);
      return decode["data"];
    } catch (e) {
      rethrow;
    }
  }
}
